@@ -47,7 +47,8 @@
 (eval-when-compile
   (require 'browse-url)
   (require 'font-lock)
-  (require 'imenu))
+  (require 'imenu)
+  (require 'sendmail))
 
 ;;{{{ user variables
 
@@ -219,8 +220,8 @@ More specifically:
   (make-local-variable 'sgml-default-doctype-name)
   (setq sgml-declaration             (expand-file-name "html.decl"
 						       sgml-data-directory)
-	sgml-default-doctype-name    "html"
-	sgml-always-quote-attributes t 
+	sgml-default-doctype-name    "HTML"
+	sgml-always-quote-attributes t
 	sgml-indent-step             2
 	sgml-indent-data	     t
 	sgml-inhibit-indent-tags     '("pre")
@@ -246,7 +247,7 @@ More specifically:
 	 (setq font-lock-keywords-case-fold-search t)
 	 (setq font-lock-keywords html-font-lock-keywords)
 	 (setq font-lock-no-comments t)))
-  
+
   (if html-helper-do-write-file-hooks
       (add-hook 'local-write-file-hooks 'html-helper-update-timestamp))
 
@@ -264,8 +265,11 @@ More specifically:
   (modify-syntax-entry ?'  "w   " html-mode-syntax-table)
 
   (tempo-use-tag-list 'html-helper-tempo-tags html-helper-completion-finder)
-  (setq imenu-create-index-function 'html-helper-imenu-index)
-  (setq imenu-sort-function nil) ; sorting the menu defeats the purpose
+  (set (make-local-variable 'imenu-create-index-function)
+       'html-helper-imenu-index)
+  (set (make-local-variable 'imenu-sort-function) nil) ; sorting the
+						       ; menu defeats
+						       ; the purpose
 
   ; sigh ...  need to call this now to get things working.
   (sgml-build-custom-menus)
@@ -427,7 +431,7 @@ appropriate keymap if a key is requested. Format:
    (entity  "\C-c&"   "&amp;"		"Ampersand"	 ("&amp;"))
    (entity  "\C-c>"   "&gt;"	  	"Greater Than"   ("&gt;"))
    (entity  "\C-c<"   "&lt;"		"Less Than"	 ("&lt;"))
-   
+
    ;; logical styles
    (logical "v"       "<div"            "Text Division"  ("<div align=\"" (r "Alignment: ") "\">" (r "Text: ") "</div>"))
    (logical "n"       "<center>"        "Center"         ("<center>" (r "Text: ") "</center>"))
@@ -493,7 +497,7 @@ appropriate keymap if a key is requested. Format:
 
    ;;anchors
    (anchor  "n"	      "<a name="	"Link Target"	 ("<a name=\"" (p "Anchor name: ") "\">" (r "Anchor text: ") "</a>"))
-   (anchor  "h"	      "<a href="        "Hyperlink"      ("<a href=\"" (p "URL: ") "\">" (r "Anchor text: ") "</a>"))                
+   (anchor  "h"	      "<a href="        "Hyperlink"      ("<a href=\"" (p "URL: ") "\">" (r "Anchor text: ") "</a>"))
 
    ;;graphics
    (image   "m"       "<map name="      "Image map"      ("<map name=\"" (r "Map name: ") "\">"))
@@ -591,12 +595,20 @@ This function can be called again, it redoes the entire menu."
 	(setq html-helper-mode-menu
 	      (cons '["Load this Buffer in Browser" browse-url-of-file t]
 		    html-helper-mode-menu)))
-    (if (and (boundp 'browse-url-browser-function)
-	     (fboundp browse-url-browser-function))
-	(setq html-helper-mode-menu
-	      (cons (vector "Browse URL at point"
-			    browse-url-browser-function t)
-		    html-helper-mode-menu)))
+    (setq html-helper-mode-menu
+          (cons (vector "Browse URL at point"
+                        (when (and (boundp 'browse-url-browser-function)
+                                   browse-url-browser-function)
+                          ;; If the value is not a function it should be a list of pairs
+                          ;; (REGEXP . FUNCTION)
+                          (cond
+                           ((functionp browse-url-browser-function))
+                           ((listp browse-url-browser-function)
+                            (dolist (elt browse-url-browser-function)
+                              (when (not (string-match "mail" (symbol-name (cdr-safe elt))))
+                                (return (cdr elt)))))))
+                        t)
+                html-helper-mode-menu))
 
     ;; cons in the timestamp delimiters
     (setq html-helper-mode-menu
@@ -686,6 +698,7 @@ This function can be called again, it redoes the entire menu."
     (defvar font-lock-reference-face 'underline ; Ugly at line breaks
       "Face to use for references -- including HTML hyperlink texts.")))
 
+;;;###autoload
 (defvar html-font-lock-keywords
   (let (;; Titles and H1's, like function defs.
 	;;   We allow for HTML 3.0 attributes, like `<h1 align=center>'.
