@@ -1,5 +1,5 @@
 ;;; psgml.el --- SGML-editing mode with parsing support
-;; $Id: psgml.el,v 1.12 2001/01/14 04:08:23 youngs Exp $
+;; $Id: psgml.el,v 1.16 2002/08/12 21:43:11 scop Exp $
 
 ;; Copyright (C) 1993-1999 Lennart Staflin
 ;; Copyright (C) 1992 Free Software Foundation, Inc.
@@ -627,13 +627,13 @@ See `compilation-error-regexp-alist'.")
 
 (defcustom sgml-declaration nil
   "*If non-nil, this is the name of the SGML declaration file."
-  :type 'file
+  :type '(choice (const nil) file)
   :group 'psgml-dtd)
 (put 'sgml-declaration 'sgml-type 'file-or-nil)
 
 (defcustom sgml-xml-declaration nil
   "*If non-nil, this is the name of the SGML declaration for XML files."
-  :type 'file
+  :type '(choice (const nil) file)
   :group 'psgml-dtd)
 (put 'sgml-xml-declaration 'sgml-type 'file-or-nil)
 
@@ -1358,9 +1358,15 @@ All bindings:
   (sgml-build-custom-menus))
 
 
-
+;; XEmacs hack: autoload a dummy autoload instead of a derived mode.
 ;;;###autoload
+(autoload 'xml-mode "psgml")
 (define-derived-mode xml-mode sgml-mode "XML"
+  ;; XEmacs change
+  (cond
+   (running-xemacs
+    (require 'psgml-html)
+    (put 'xml-mode 'font-lock-defaults '(html-font-lock-keywords nil t))))
   (setq sgml-xml-p t)
   ;; XML-friendly settings
   (setq sgml-omittag nil)
